@@ -267,7 +267,7 @@ public:
     /// \param info Additional info that will be appended to the beginning of the error message.
     database_error(void* handle, short handle_type, const std::string& info = "");
     const char* what() const NANODBC_NOEXCEPT;
-    const long native() const NANODBC_NOEXCEPT;
+    long native() const NANODBC_NOEXCEPT;
     const std::string state() const NANODBC_NOEXCEPT;
 
 private:
@@ -915,6 +915,31 @@ public:
 
     /// @}
 
+    /// \brief Sets descriptions for parameters in the prepared statement.
+    ///
+    /// If your prepared SQL query has any parameter markers, ? (question  mark)
+    /// placeholders this is how you can describe the SQL type, size and scale
+    /// for some or all of the parameters, prior to binding any data to the
+    /// parameters.  Calling this method is optional: if a parameter is not
+    /// described using a call to this method, then during a bind an attempt is
+    /// made to identify it using a call to the ODBC SQLDescribeParam API handle.
+    /// Once set, description is re-used for possibly repeated binds
+    /// execution and only cleared when the statement is cleared / destroyed.
+    /// Parameter markers are numbered using Zero-based index from left to right.
+    ///
+    /// \param idx Vector of zero-based indices of parameters we are describing.
+    /// \param type Vector of (short integer) types.
+    /// \param size Vector of (unsigned long) sizes.
+    /// \param scale Vector of (short integer) decimal precision / scale.
+    /// \throws programming_error
+    void describe_parameters(
+        const std::vector<short>& idx,
+        const std::vector<short>& type,
+        const std::vector<unsigned long>& size,
+        const std::vector<short>& scale);
+
+    /// @}
+
 private:
     typedef std::function<bool(std::size_t)> null_predicate_type;
 
@@ -986,6 +1011,20 @@ public:
     /// If you explicitly need to know if disconnect() succeeds, call it directly.
     ~connection() NANODBC_NOEXCEPT;
 
+    /// \brief Allocate environment and connection handles.
+    ///
+    /// Allows on-demand allocation of handles to configure the ODBC environment
+    /// and attributes, before database connection is established.
+    /// Typically, user does not have to make this call explicitly.
+    ///
+    /// \throws database_error
+    /// \see deallocate()
+    void allocate();
+
+    /// \brief Release environment and connection handles.
+    /// \see allocate()
+    void deallocate();
+
     /// \brief Connect to the given data source.
     /// \param dsn The name of the data source.
     /// \param user The username for authenticating to the data source.
