@@ -21,6 +21,7 @@ public:
   odbc_connection(
       std::string connection_string,
       std::string timezone = "UTC",
+      std::string timezone_out = "UTC",
       std::string encoding = "",
       bigint_map_t bigint_mapping = i64_to_integer64,
       long timeout = 0);
@@ -37,6 +38,7 @@ public:
   void set_current_result(odbc_result* r);
 
   cctz::time_zone timezone() const;
+  std::string timezone_out_str() const;
   std::string encoding() const;
 
   bigint_map_t get_bigint_mapping() const;
@@ -46,6 +48,8 @@ private:
   std::unique_ptr<nanodbc::transaction> t_;
   odbc_result* current_result_;
   cctz::time_zone timezone_;
+  cctz::time_zone timezone_out_;
+  std::string timezone_out_str_;
   std::string encoding_;
   bigint_map_t bigint_mapping_;
 };
