@@ -13,7 +13,6 @@ test_that("SQLServer", {
     "connect_bigint_integer64",
       NULL))
   DBItest::test_connection(c(
-      "cannot_forget_disconnect", # TODO
       NULL))
   DBItest::test_result(c(
       "fetch_n_bad",                     # TODO
@@ -33,38 +32,29 @@ test_that("SQLServer", {
       "execute_immediate", # Invalid CTAS syntax
       "data_character", # I think the test is bad
       "data_logical$", # Not an error
-      "data_logical_.*", # Not an error
       "data_64_bit_numeric_warning", # Test does not explicitly set 64 bit columns
       "data_64_bit_lossless", # Test does not explicitly set 64 bit columns
       "data_date.*", # Date not a builtin function name
       "data_raw.*", # cast(1 bytea) is not valid `cannot cast type integer to bytea`
       "^data_time$", "^data_time_.*", # time objects not supported
       "^data_timestamp.*", # syntax not supported
-      "^data_timestamp_parens.*", # syntax not supported
       NULL))
   DBItest::test_sql(c(
       "append_roundtrip_.*", # TODO
       "quote_string_na_is_null", # Invalid syntax
       "quote_identifier_vectorized", # TODO
-      "quote_identifier_not_vectorized", # Can't implement until https://github.com/rstats-db/DBI/issues/71 is closed
       "quote_identifier", # Invalid Syntax
       "quote_identifier_special", # TODO
       "remove_table_temporary_arg",
       "remove_table_missing_succeed",
       "remove_table_missing_succeed",
-      "roundtrip_logical_int", # Not an error, PostgreSQL has a logical data type
-      "roundtrip_64_bit", # TODO
       "temporary_table", # Unsupported
-      "roundtrip_numeric_special", # Unsupported
       "roundtrip_character", # #10
       "roundtrip_character_native", # Possible false positive
       "roundtrip_factor", # #10
-      "roundtrip_raw", # #10
-      "roundtrip_blob", # TODO
       "roundtrip_time", #TODO
       "roundtrip_date", # unsupported
       "roundtrip_quotes", # TODO, not sure why this is failing
-      "roundtrip_rownames", # #10
       "roundtrip_timestamp", # We explicitly want to set tzone to UTC regardless of input
       "write_table_error", # TODO
       "list_tables", # TODO
@@ -100,7 +90,6 @@ test_that("SQLServer", {
    DBItest::test_transaction(c(
        NULL))
   DBItest::test_compliance(c(
-      "read_only", # Setting SQL_MODE_READ_ONLY is not supported in most DBs, so ignoring.
       "compliance", # We are defining additional subclasses for OdbcConnections
       "reexport",
       NULL))
@@ -108,6 +97,7 @@ test_that("SQLServer", {
   local({
     # SQLServer works with schemas (#197)
     con <- DBItest:::connect(DBItest:::get_default_context())
+    dbExecute(con, "DROP SCHEMA IF EXISTS testSchema")
     dbExecute(con, 'CREATE SCHEMA testSchema')
     on.exit({
       dbExecute(con, "DROP TABLE testSchema.iris")
