@@ -7,21 +7,18 @@ test_that("SQLite", {
       "package_name", # Not an error
       NULL))
   DBItest::test_driver(c(
+      "connect_format",
       "connect_bigint_numeric",
       "connect_bigint_character",
       "connect_bigint_integer64",
       NULL))
   DBItest::test_connection(c(
       "data_type_connection",
-      "cannot_forget_disconnect",
       NULL))
   DBItest::test_result(c(
       "data_logical$", # Not an error
-      "data_logical_.*", # Not an error
       "data_64_bit.*", # TODO
       "data_integer", # These tests are returned as strings by SQLite (bug?)
-      "data_integer_null.*", # These tests are returned as strings by SQLite (bug?)
-      "data_numeric_null.*", # These tests are returned as strings by SQLite (bug?)
       "data_raw.*", # cast(1 bytea) is not valid `cannot cast type integer to bytea`
       "^data_time$", "^data_time_.*", # time objects not supported
       "^data_timestamp.*", # SQLite doesn't do timestamps
@@ -78,7 +75,6 @@ test_that("SQLite", {
       "temporary_table", # TODO
       "table_visible_in_other_connection", # TODO
       "roundtrip_64_bit_roundtrip", # TODO
-      "roundtrip_blob", # TODO
       "roundtrip_time", # TODO
       "roundtrip_field_types", # TODO
       "write_table_row_names_.*", # TODO
